@@ -124,7 +124,15 @@ def get_engine(*pairs, **connection):
         e = sa.create_engine(cstr)       
     return e
     
-_types = {str: String, int : Integer, float: Float, datetime.date: DATE, datetime.datetime : DATETIME, datetime.time: TIME}
+_types = {str: String, 'str' : String, 
+          int : Integer, 'int' : Integer,
+          float: Float, 
+          'dec' : sa.DECIMAL(0), 'dec1' : sa.DECIMAL(1), 'dec2' : sa.DECIMAL(2), 'dec3' : sa.DECIMAL(3), 'dec4' : sa.DECIMAL(4), 'dec5' : sa.DECIMAL(5), 
+          datetime.date: DATE, 'date' : DATE,
+          datetime.datetime : DATETIME, 'datetime' : DATETIME,
+          datetime.time: TIME, 'time' : TIME,
+          bin : sa.VARBINARY}
+
 _orders = {1 : asc, True: asc, 'asc': asc, asc : asc, -1: desc, False: desc, 'desc': desc, desc: desc}
 
 
